@@ -12,7 +12,9 @@ Usage:
 from __future__ import absolute_import, division
 
 # import compatibility functions and utilities
+import re
 import sys
+from weakref import proxy
 
 # to inherit from the tqdm class
 from .std import tqdm as std_tqdm
@@ -21,14 +23,9 @@ from .utils import _range
 if True:  # pragma: no cover
     # import IPython/Jupyter base widget and display utilities
     IPY = 0
-    IPYW = 0
     try:  # IPython 4.x
         import ipywidgets
         IPY = 4
-        try:
-            IPYW = int(ipywidgets.__version__.split('.')[0])
-        except AttributeError:  # __version__ may not exist in old versions
-            pass
     except ImportError:  # IPython 3.x / 2.x
         IPY = 32
         import warnings
@@ -36,7 +33,7 @@ if True:  # pragma: no cover
             warnings.filterwarnings(
                 'ignore', message=".*The `IPython.html` package has been deprecated.*")
             try:
-                import IPython.html.widgets as ipywidgets
+                import IPython.html.widgets as ipywidgets  # NOQA: F401
             except ImportError:
                 pass
 
@@ -74,24 +71,27 @@ if True:  # pragma: no cover
 
 __author__ = {"github.com/": ["lrq3000", "casperdcl", "alexanderkuk"]}
 __all__ = ['tqdm_notebook', 'tnrange', 'tqdm', 'trange']
+WARN_NOIPYW = ("IProgress not found. Please update jupyter and ipywidgets."
+               " See https://ipywidgets.readthedocs.io/en/stable"
+               "/user_install.html")
 
 
 class TqdmHBox(HBox):
     """`ipywidgets.HBox` with a pretty representation"""
     def _repr_json_(self, pretty=None):
-        if not hasattr(self, "pbar"):
+        pbar = getattr(self, 'pbar', None)
+        if pbar is None:
             return {}
-        d = dict(self.pbar.format_dict,
-                 bar_format=(self.pbar.format_dict['bar_format']
-                             or "{l_bar}{bar}{r_bar}").replace("<bar/>", "{bar}"))
+        d = pbar.format_dict
         if pretty is not None:
             d["ascii"] = not pretty
         return d
 
     def __repr__(self, pretty=False):
-        if not hasattr(self, "pbar"):
+        pbar = getattr(self, 'pbar', None)
+        if pbar is None:
             return super(TqdmHBox, self).__repr__()
-        return self.pbar.format_meter(**self._repr_json_(pretty))
+        return pbar.format_meter(**self._repr_json_(pretty))
 
     def _repr_pretty_(self, pp, *_, **__):
         pp.text(self.__repr__(True))
@@ -115,10 +115,7 @@ class tqdm_notebook(std_tqdm):
 
         # Prepare IPython progress bar
         if IProgress is None:  # #187 #451 #558 #872
-            raise ImportError(
-                "IProgress not found. Please update jupyter and ipywidgets."
-                " See https://ipywidgets.readthedocs.io/en/stable"
-                "/user_install.html")
+            raise ImportError(WARN_NOIPYW)
         if total:
             pbar = IProgress(min=0, max=total)
         else:  # No total? Show info style bar with no progress tqdm status
@@ -149,16 +146,9 @@ class tqdm_notebook(std_tqdm):
 
         return container
 
-    @staticmethod
-    def format_meter(n, total, *args, **kwargs):
-        if total and kwargs.get('bar_format', None) is None:
-            kwargs = kwargs.copy()
-            kwargs['bar_format'] = "{l_bar}<bar/>{r_bar}"
-        return std_tqdm.format_meter(n, total, *args, **kwargs)
-
     def display(self, msg=None, pos=None,
                 # additional signals
-                close=False, bar_style=None):
+                close=False, bar_style=None, check_delay=True):
         # Note: contrary to native tqdm, msg='' does NOT clear bar
         # goal is to keep all infos if error happens so user knows
         # at which iteration the loop failed.
@@ -167,7 +157,11 @@ class tqdm_notebook(std_tqdm):
         # clear_output(wait=1)
 
         if not msg and not close:
-            msg = self.__repr__()
+            d = self.format_dict
+            # remove {bar}
+            d['bar_format'] = (d['bar_format'] or "{l_bar}<bar/>{r_bar}").replace(
+                "{bar}", "<bar/>")
+            msg = self.format_meter(**d)
 
         ltext, pbar, rtext = self.container.children
         pbar.value = self.n
@@ -175,16 +169,10 @@ class tqdm_notebook(std_tqdm):
         if msg:
             # html escape special characters (like '&')
             if '<bar/>' in msg:
-                left, right = map(escape, msg.split('<bar/>', 1))
+                left, right = map(escape, re.split(r'\|?<bar/>\|?', msg, 1))
             else:
                 left, right = '', escape(msg)
 
-            # remove inesthetical pipes
-            if left and left[-1] == '|':
-                left = left[:-1]
-            if right and right[0] == '|':
-                right = right[1:]
-
             # Update description
             ltext.value = left
             # never clear the bar (signal: msg='')
@@ -195,7 +183,7 @@ class tqdm_notebook(std_tqdm):
         if bar_style:
             # Hack-ish way to avoid the danger bar_style being overridden by
             # success because the bar gets closed after the error...
-            if not (pbar.bar_style == 'danger' and bar_style == 'success'):
+            if pbar.bar_style != 'danger' or bar_style != 'success':
                 pbar.bar_style = bar_style
 
         # Special signal to close the bar
@@ -205,6 +193,10 @@ class tqdm_notebook(std_tqdm):
             except AttributeError:
                 self.container.visible = False
 
+        if check_delay and self.delay > 0 and not self.displayed:
+            display(self.container)
+            self.displayed = True
+
     @property
     def colour(self):
         if hasattr(self, 'container'):
@@ -232,8 +224,6 @@ class tqdm_notebook(std_tqdm):
 
         # Initialize parent class + avoid printing by using gui=True
         kwargs['gui'] = True
-        if 'bar_format' in kwargs:
-            kwargs['bar_format'] = kwargs['bar_format'].replace('{bar}', '<bar/>')
         # convert disable = None to False
         kwargs['disable'] = bool(kwargs.get('disable', False))
         colour = kwargs.pop('colour', None)
@@ -250,19 +240,21 @@ class tqdm_notebook(std_tqdm):
         unit_scale = 1 if self.unit_scale is True else self.unit_scale or 1
         total = self.total * unit_scale if self.total else self.total
         self.container = self.status_printer(self.fp, total, self.desc, self.ncols)
-        self.container.pbar = self
-        if display_here:
+        self.container.pbar = proxy(self)
+        self.displayed = False
+        if display_here and self.delay <= 0:
             display(self.container)
+            self.displayed = True
         self.disp = self.display
         self.colour = colour
 
         # Print initial bar state
         if not self.disable:
-            self.display()
+            self.display(check_delay=False)
 
-    def __iter__(self, *args, **kwargs):
+    def __iter__(self):
         try:
-            for obj in super(tqdm_notebook, self).__iter__(*args, **kwargs):
+            for obj in super(tqdm_notebook, self).__iter__():
                 # return super(tqdm...) will not catch exception
                 yield obj
         # NB: except ... [ as ...] breaks IPython async KeyboardInterrupt
@@ -272,9 +264,9 @@ class tqdm_notebook(std_tqdm):
         # NB: don't `finally: close()`
         # since this could be a shared bar which the user will `reset()`
 
-    def update(self, *args, **kwargs):
+    def update(self, n=1):
         try:
-            return super(tqdm_notebook, self).update(*args, **kwargs)
+            return super(tqdm_notebook, self).update(n=n)
         # NB: except ... [ as ...] breaks IPython async KeyboardInterrupt
         except:  # NOQA
             # cannot catch KeyboardInterrupt when using manual tqdm
@@ -284,17 +276,19 @@ class tqdm_notebook(std_tqdm):
         # NB: don't `finally: close()`
         # since this could be a shared bar which the user will `reset()`
 
-    def close(self, *args, **kwargs):
-        super(tqdm_notebook, self).close(*args, **kwargs)
+    def close(self):
+        if self.disable:
+            return
+        super(tqdm_notebook, self).close()
         # Try to detect if there was an error or KeyboardInterrupt
         # in manual mode: if n < total, things probably got wrong
         if self.total and self.n < self.total:
-            self.disp(bar_style='danger')
+            self.disp(bar_style='danger', check_delay=False)
         else:
             if self.leave:
-                self.disp(bar_style='success')
+                self.disp(bar_style='success', check_delay=False)
             else:
-                self.disp(close=True)
+                self.disp(close=True, check_delay=False)
 
     def clear(self, *_, **__):
         pass
@@ -309,6 +303,8 @@ class tqdm_notebook(std_tqdm):
         ----------
         total  : int or float, optional. Total to use for the new bar.
         """
+        if self.disable:
+            return super(tqdm_notebook, self).reset(total=total)
         _, pbar, _ = self.container.children
         pbar.bar_style = ''
         if total is not None:
